https://github.com/RetroShare/RetroShare/commit/8bed99cc9f3763269b6b1aada45a43c9993d7b80
From: Gioacchino Mazzurco <gio@eigenlab.org>
Date: Fri, 6 Aug 2021 12:15:34 +0200
Subject: [PATCH] Fix compilation with C++17
--- a/libretroshare/src/util/rsdir.cc
+++ b/libretroshare/src/util/rsdir.cc
@@ -64,6 +64,26 @@
  * #define RSDIR_DEBUG 1
  ****/
 
+#if __cplusplus < 201703L
+bool std::filesystem::create_directories(const std::string& path)
+{
+	for( std::string::size_type lastIndex = 0; lastIndex < std::string::npos;
+	     lastIndex = path.find('/', lastIndex) )
+	{
+		std::string&& curDir = path.substr(0, ++lastIndex);
+		if(!RsDirUtil::checkCreateDirectory(curDir))
+		{
+			RsErr() << __PRETTY_FUNCTION__ << " failure creating: " << curDir
+			        << " of: " << path << std::endl;
+			return false;
+		}
+	}
+	return true;
+}
+#else
+#	include <filesystem>
+#endif // __cplusplus < 201703L
+
 std::string 	RsDirUtil::getTopDir(const std::string& dir)
 {
 	std::string top;
@@ -528,24 +548,6 @@ bool RsDirUtil::checkCreateDirectory(const std::string& dir)
 	return true;
 }
 
-#if __cplusplus < 201703L
-bool std::filesystem::create_directories(const std::string& path)
-{
-	for( std::string::size_type lastIndex = 0; lastIndex < std::string::npos;
-	     lastIndex = path.find('/', lastIndex) )
-	{
-		std::string&& curDir = path.substr(0, ++lastIndex);
-		if(!RsDirUtil::checkCreateDirectory(curDir))
-		{
-			RsErr() << __PRETTY_FUNCTION__ << " failure creating: " << curDir
-			        << " of: " << path << std::endl;
-			return false;
-		}
-	}
-	return true;
-}
-#endif // __cplusplus < 201703L
-
 std::string RsDirUtil::removeSymLinks(const std::string& path)
 {
 #if defined(WINDOWS_SYS) || defined(__APPLE__) || defined(__ANDROID__)
